==> jboss-3.2.7-src.tar.bz2: jboss-3.2.7-src/jmx-remoting/src/main/org/jboss/mx/remoting/ClientListener.java <==
/***************************************
 *                                     *
 *  JBoss: The OpenSource J2EE WebOS   *
 *                                     *
 *  Distributable under LGPL license.  *
 *  See terms of license at gnu.org.   *
 *                                     *
 ***************************************/
package org.jboss.mx.remoting;

import java.util.HashMap;
import java.util.Map;
import java.util.Collections;
import javax.management.ObjectName;
import javax.management.NotificationFilter;

/**
 * ClientListener
 *
 * @author <a href="mailto:jhaynie@vocalocity.net">Jeff Haynie</a>
 * @version $Revision: 1.1.2.2 $
 */
public class ClientListener
{
    final ObjectName objectName;
    final Object listener;
    final NotificationFilter filter;
    final Object handback;
    final String sessionId;

    private static final Map listeners = Collections.synchronizedMap(new HashMap());

    private ClientListener ( String sessionId, ObjectName objectName, Object listener, NotificationFilter filter, Object handback )
    {
        this.sessionId = sessionId;
        this.objectName = objectName;
        this.listener = listener;
        this.filter = filter;
        this.handback = handback;
    }

    public String toString ()
    {
        return "ClientListener [sessionid:"+sessionId+",objectName:"+objectName+",listener:"+listener+",filter:"+filter+",handback:"+handback+"]";
    }

    public static boolean hasListeners ()
    {
        return listeners.isEmpty()==false;
    }

    public static Object makeId (String sessionId, ObjectName objectName, Object listener)
    {
        return sessionId + "/"+ objectName + "/" + listener;
    }

    public static ClientListener remove (Object id)
    {
        return (ClientListener)listeners.remove(id);
    }

    public static ClientListener remove(String sessionId, ObjectName objectName, Object listener)
    {
        Object id = null;
        if (listener instanceof ClientListener)
        {
            id = makeId(sessionId,objectName,((ClientListener)listener).listener);
        }
        else
        {
            id = makeId(sessionId,objectName,listener);
        }
        return (ClientListener)listeners.remove(id);
    }

    public static Object register(String sessionId, ObjectName objectName, Object listener, NotificationFilter filter, Object handback)
    {
        ClientListener l = new ClientListener(sessionId,objectName,listener,filter,handback);
        Object id = makeId(sessionId,objectName,listener);
        listeners.put(id,l);
        return id;
    }

    public static ClientListener get(Object id)
    {
        return (ClientListener)listeners.get(id);
    }

    static String dump()
    {
        return listeners.toString();
    }

}

==> jboss-4.0.2-src.tar.bz2: jboss-4.0.2-src/jmx-remoting/src/main/org/jboss/mx/remoting/ClientListener.java <==
/***************************************
 *                                     *
 *  JBoss: The OpenSource J2EE WebOS   *
 *                                     *
 *  Distributable under LGPL license.  *
 *  See terms of license at gnu.org.   *
 *                                     *
 ***************************************/
package org.jboss.mx.remoting;

import java.util.HashMap;
import java.util.Map;
import javax.management.ObjectName;
import javax.management.NotificationFilter;

/**
 * ClientListener
 *
 * @author <a href="mailto:jhaynie@vocalocity.net">Jeff Haynie</a>
 * @version $Revision: 1.1 $
 */
public class ClientListener
{
    final ObjectName objectName;
    final Object listener;
    final NotificationFilter filter;
    final Object handback;
    final String sessionId;

    private static final Map listeners=new HashMap();

    private ClientListener ( String sessionId, ObjectName objectName, Object listener, NotificationFilter filter, Object handback )
    {
        this.sessionId = sessionId;
        this.objectName = objectName;
        this.listener = listener;
        this.filter = filter;
        this.handback = handback;
    }

    public String toString ()
    {
        return "ClientListener [sessionid:"+sessionId+",objectName:"+objectName+",listener:"+listener+",filter:"+filter+",handback:"+handback+"]";
    }

    public static boolean hasListeners ()
    {
        return listeners.isEmpty()==false;
    }

    public static Object makeId (String sessionId, ObjectName objectName, Object listener)
    {
        return sessionId + "/"+ objectName + "/" + listener;
    }
    public static synchronized ClientListener remove (Object id)
    {
        return (ClientListener)listeners.remove(id);
    }
    public static synchronized ClientListener remove (String sessionId, ObjectName objectName, Object listener)
    {
        Object id = null;
        if (listener instanceof ClientListener)
        {
            id = makeId(sessionId,objectName,((ClientListener)listener).listener);
        }
        else
        {
            id = makeId(sessionId,objectName,listener);
        }
        return (ClientListener)listeners.remove(id);
    }
    public static synchronized Object register (String sessionId, ObjectName objectName, Object listener, NotificationFilter filter, Object handback)
    {
        ClientListener l = new ClientListener(sessionId,objectName,listener,filter,handback);
        Object id = makeId(sessionId,objectName,listener);
        listeners.put(id,l);
        return id;
    }
    public static synchronized ClientListener get (Object id)
    {
        return (ClientListener)listeners.get(id);
    }
    static synchronized String dump ()
    {
        return listeners.toString();
    }

}
